.. _coders:

CanSig for Pythonists
=====================  
For custom applications, one may use CanSig as a Python package in a script or a `Jupyter notebook <https://jupyter.org/>`_.

Here is a `tutorial in Google Colab <https://colab.research.google.com/drive/1GSGIqvp_kkG05n0qTY_aYxaDJqllRDWb?usp=sharing>`_ for a quick start.

You can take a look at the API for more details.
